summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorRobert Cohn <robert.s.cohn@intel.com>2022-06-17 00:23:40 -0700
committerGitHub <noreply@github.com>2022-06-17 09:23:40 +0200
commit466572dc14efcfd2054b52ee935dc809a39f1893 (patch)
tree71f3a99fc4db3638189d40c44c1a39e8c534a82b
parent1c0bf12e5b21de3d77af2b1025479d30c4c94400 (diff)
downloadspack-466572dc14efcfd2054b52ee935dc809a39f1893.tar.gz
spack-466572dc14efcfd2054b52ee935dc809a39f1893.tar.bz2
spack-466572dc14efcfd2054b52ee935dc809a39f1893.tar.xz
spack-466572dc14efcfd2054b52ee935dc809a39f1893.zip
Update Intel package descriptions (#31150)
-rw-r--r--lib/spack/docs/build_systems/inteloneapipackage.rst8
-rw-r--r--lib/spack/docs/build_systems/intelpackage.rst3
-rw-r--r--var/spack/repos/builtin/packages/intel-daal/package.py6
-rw-r--r--var/spack/repos/builtin/packages/intel-ipp/package.py8
-rw-r--r--var/spack/repos/builtin/packages/intel-mkl/package.py6
-rw-r--r--var/spack/repos/builtin/packages/intel-mpi-benchmarks/package.py15
-rw-r--r--var/spack/repos/builtin/packages/intel-mpi/package.py5
-rw-r--r--var/spack/repos/builtin/packages/intel-oneapi-ccl/package.py10
-rw-r--r--var/spack/repos/builtin/packages/intel-oneapi-dal/package.py13
-rw-r--r--var/spack/repos/builtin/packages/intel-oneapi-dnn/package.py11
-rw-r--r--var/spack/repos/builtin/packages/intel-oneapi-dpct/package.py7
-rw-r--r--var/spack/repos/builtin/packages/intel-oneapi-dpl/package.py9
-rw-r--r--var/spack/repos/builtin/packages/intel-oneapi-ipp/package.py13
-rw-r--r--var/spack/repos/builtin/packages/intel-oneapi-ippcp/package.py13
-rw-r--r--var/spack/repos/builtin/packages/intel-oneapi-mkl/package.py9
-rw-r--r--var/spack/repos/builtin/packages/intel-oneapi-mpi/package.py8
-rw-r--r--var/spack/repos/builtin/packages/intel-oneapi-tbb/package.py7
-rw-r--r--var/spack/repos/builtin/packages/intel-parallel-studio/package.py6
-rw-r--r--var/spack/repos/builtin/packages/intel/package.py6
19 files changed, 133 insertions, 30 deletions
diff --git a/lib/spack/docs/build_systems/inteloneapipackage.rst b/lib/spack/docs/build_systems/inteloneapipackage.rst
index a2468c67c6..fe6aea91bb 100644
--- a/lib/spack/docs/build_systems/inteloneapipackage.rst
+++ b/lib/spack/docs/build_systems/inteloneapipackage.rst
@@ -84,8 +84,8 @@ build ``hdf5`` with Intel oneAPI MPI do::
spack install hdf5 +mpi ^intel-oneapi-mpi
-Using an Externally Installed oneAPI
-====================================
+Using Externally Installed oneAPI Tools
+=======================================
Spack can also use oneAPI tools that are manually installed with
`Intel Installers`_. The procedures for configuring Spack to use
@@ -110,7 +110,7 @@ Another option is to manually add the configuration to
Libraries
---------
-If you want Spack to use MKL that you have installed without Spack in
+If you want Spack to use oneMKL that you have installed without Spack in
the default location, then add the following to
``~/.spack/packages.yaml``, adjusting the version as appropriate::
@@ -139,7 +139,7 @@ You can also use Spack-installed libraries. For example::
spack load intel-oneapi-mkl
Will update your environment CPATH, LIBRARY_PATH, and other
-environment variables for building an application with MKL.
+environment variables for building an application with oneMKL.
More information
================
diff --git a/lib/spack/docs/build_systems/intelpackage.rst b/lib/spack/docs/build_systems/intelpackage.rst
index 5da16157d7..4a59b75104 100644
--- a/lib/spack/docs/build_systems/intelpackage.rst
+++ b/lib/spack/docs/build_systems/intelpackage.rst
@@ -15,6 +15,9 @@ IntelPackage
Intel packages in Spack
^^^^^^^^^^^^^^^^^^^^^^^^
+This is an earlier version of Intel software development tools and has
+now been replaced by Intel oneAPI Toolkits.
+
Spack can install and use several software development products offered by Intel.
Some of these are available under no-cost terms, others require a paid license.
All share the same basic steps for configuration, installation, and, where
diff --git a/var/spack/repos/builtin/packages/intel-mpi-benchmarks/package.py b/var/spack/repos/builtin/packages/intel-mpi-benchmarks/package.py
index 863d58e89d..f3a29081bb 100644
--- a/var/spack/repos/builtin/packages/intel-mpi-benchmarks/package.py
+++ b/var/spack/repos/builtin/packages/intel-mpi-benchmarks/package.py
@@ -6,13 +6,16 @@
from spack.package import *
+@IntelOneApiPackage.update_description
class IntelMpiBenchmarks(MakefilePackage):
- """Intel(R) MPI Benchmarks provides a set of elementary benchmarks
- that conform to MPI-1, MPI-2, and MPI-3 standard.
- You can run all of the supported benchmarks, or a subset specified
- in the command line using one executable file.
- Use command-line parameters to specify various settings, such as
- time measurement, message lengths, and selection of communicators. """
+ """Intel MPI Benchmarks provides a set of elementary benchmarks that
+ conform to MPI-1, MPI-2, and MPI-3 standard. You can run all of
+ the supported benchmarks, or a subset specified in the command
+ line using one executable file. Use command-line parameters to
+ specify various settings, such as time measurement, message
+ lengths, and selection of communicators.
+
+ """
homepage = "https://software.intel.com/en-us/articles/intel-mpi-benchmarks"
url = "https://github.com/intel/mpi-benchmarks/archive/IMB-v2019.5.tar.gz"
diff --git a/var/spack/repos/builtin/packages/intel-mpi/package.py b/var/spack/repos/builtin/packages/intel-mpi/package.py
index 49a6433e6a..844035d384 100644
--- a/var/spack/repos/builtin/packages/intel-mpi/package.py
+++ b/var/spack/repos/builtin/packages/intel-mpi/package.py
@@ -6,8 +6,11 @@
from spack.package import *
+@IntelOneApiPackage.update_description
class IntelMpi(IntelPackage):
- """Intel MPI"""
+ """Intel MPI. This package has been replaced by intel-oneapi-mpi.
+
+ """
maintainers = ['rscohn2']
diff --git a/var/spack/repos/builtin/packages/intel-oneapi-dal/package.py b/var/spack/repos/builtin/packages/intel-oneapi-dal/package.py
index c101db5dc5..0870d24def 100644
--- a/var/spack/repos/builtin/packages/intel-oneapi-dal/package.py
+++ b/var/spack/repos/builtin/packages/intel-oneapi-dal/package.py
@@ -11,11 +11,14 @@ from spack.package import *
@IntelOneApiPackage.update_description
class IntelOneapiDal(IntelOneApiLibraryPackage):
- """Intel Data Analytics Library (DAL) provides the right tools to
- build compute-intense applications that run fast on Intel
- architecture. It includes algorithms for analysis functions, math
- functions, training and library prediction functions for C++ and
- Java.
+ """Intel oneAPI Data Analytics Library (oneDAL) is a library that
+ helps speed up big data analysis by providing highly optimized
+ algorithmic building blocks for all stages of data analytics
+ (preprocessing, transformation, analysis, modeling, validation,
+ and decision making) in batch, online, and distributed
+ processing modes of computation. The library optimizes data
+ ingestion along with algorithmic computation to increase
+ throughput and scalability.
"""
diff --git a/var/spack/repos/builtin/packages/intel-oneapi-dnn/package.py b/var/spack/repos/builtin/packages/intel-oneapi-dnn/package.py
index 95c37d6055..f4f720d87a 100644
--- a/var/spack/repos/builtin/packages/intel-oneapi-dnn/package.py
+++ b/var/spack/repos/builtin/packages/intel-oneapi-dnn/package.py
@@ -11,7 +11,16 @@ from spack.package import *
@IntelOneApiPackage.update_description
class IntelOneapiDnn(IntelOneApiLibraryPackage):
- """Intel oneAPI DNN."""
+ """The Intel oneAPI Deep Neural Network Library (oneDNN) helps
+ developers improve productivity and enhance the performance of
+ their deep learning frameworks. It supports key data type
+ formats, including 16 and 32-bit floating point, bfloat16, and
+ 8-bit integers and implements rich operators, including
+ convolution, matrix multiplication, pooling, batch
+ normalization, activation functions, recurrent neural network
+ (RNN) cells, and long short-term memory (LSTM) cells.
+
+ """
maintainers = ['rscohn2']
diff --git a/var/spack/repos/builtin/packages/intel-oneapi-dpct/package.py b/var/spack/repos/builtin/packages/intel-oneapi-dpct/package.py
index 9706984837..116fbcbdff 100644
--- a/var/spack/repos/builtin/packages/intel-oneapi-dpct/package.py
+++ b/var/spack/repos/builtin/packages/intel-oneapi-dpct/package.py
@@ -10,7 +10,12 @@ from spack.package import *
@IntelOneApiPackage.update_description
class IntelOneapiDpct(IntelOneApiPackage):
- """Intel oneAPI DPC++ Compatibility Tool."""
+ """The Intel DPC++ Compatibility Tool assists in migrating your
+ existing CUDA code to SYCL code. The tool ports both CUDA
+ language kernels and library API calls. Typically, 90%-95% of
+ CUDA code automatically migrates to SYCL code.
+
+ """
maintainers = ['rscohn2']
diff --git a/var/spack/repos/builtin/packages/intel-oneapi-ipp/package.py b/var/spack/repos/builtin/packages/intel-oneapi-ipp/package.py
index 8c9992e356..fda1f509d4 100644
--- a/var/spack/repos/builtin/packages/intel-oneapi-ipp/package.py
+++ b/var/spack/repos/builtin/packages/intel-oneapi-ipp/package.py
@@ -10,7 +10,18 @@ from spack.package import *
@IntelOneApiPackage.update_description
class IntelOneapiIpp(IntelOneApiLibraryPackage):
- """Intel oneAPI IPP."""
+ """Intel Integrated Performance Primitives (Intel IPP) is an extensive
+ library of ready-to-use, domain-specific functions that are
+ highly optimized for diverse Intel architectures. These
+ functions take advantage of Single Instruction, Multiple Data
+ (SIMD) instructions and improve the performance of
+ computation-intensive applications, including signal
+ processing, data compression, video processing, and
+ cryptography. The intel-oneapi-ippcp package contains support
+ for cryptography and everything else can be found in the
+ intel-oneapi-ipp package.
+
+ """
maintainers = ['rscohn2']
diff --git a/var/spack/repos/builtin/packages/intel-oneapi-ippcp/package.py b/var/spack/repos/builtin/packages/intel-oneapi-ippcp/package.py
index 0b7bfe2a73..be5beddbbc 100644
--- a/var/spack/repos/builtin/packages/intel-oneapi-ippcp/package.py
+++ b/var/spack/repos/builtin/packages/intel-oneapi-ippcp/package.py
@@ -11,7 +11,18 @@ from spack.package import *
@IntelOneApiPackage.update_description
class IntelOneapiIppcp(IntelOneApiLibraryPackage):
- """Intel oneAPI IPP Crypto."""
+ """Intel Integrated Performance Primitives (Intel IPP) is an extensive
+ library of ready-to-use, domain-specific functions that are
+ highly optimized for diverse Intel architectures. These
+ functions take advantage of Single Instruction, Multiple Data
+ (SIMD) instructions and improve the performance of
+ computation-intensive applications, including signal
+ processing, data compression, video processing, and
+ cryptography. The intel-oneapi-ippcp package contains support
+ for cryptography and everything else can be found in the
+ intel-oneapi-ipp package.
+
+ """
maintainers = ['rscohn2']
diff --git a/var/spack/repos/builtin/packages/intel-oneapi-mpi/package.py b/var/spack/repos/builtin/packages/intel-oneapi-mpi/package.py
index 29e28dafda..0582e1b2d2 100644
--- a/var/spack/repos/builtin/packages/intel-oneapi-mpi/package.py
+++ b/var/spack/repos/builtin/packages/intel-oneapi-mpi/package.py
@@ -11,7 +11,13 @@ from spack.package import *
@IntelOneApiPackage.update_description
class IntelOneapiMpi(IntelOneApiLibraryPackage):
- """Intel oneAPI MPI."""
+ """Intel MPI Library is a multifabric message-passing library that
+ implements the open-source MPICH specification. Use the library
+ to create, maintain, and test advanced, complex applications
+ that perform better on high-performance computing (HPC)
+ clusters based on Intel processors.
+
+ """
maintainers = ['rscohn2', ]
diff --git a/var/spack/repos/builtin/packages/intel-parallel-studio/package.py b/var/spack/repos/builtin/packages/intel-parallel-studio/package.py
index 4ecc89d1b8..4a6fadfa89 100644
--- a/var/spack/repos/builtin/packages/intel-parallel-studio/package.py
+++ b/var/spack/repos/builtin/packages/intel-parallel-studio/package.py
@@ -6,8 +6,12 @@
from spack.package import *
+@IntelOneApiPackage.update_description
class IntelParallelStudio(IntelPackage):
- """Intel Parallel Studio."""
+ """This is an earlier version of Intel parallel software development
+ tools and has now been replaced by the Intel oneAPI Toolkits.
+
+ """
homepage = "https://software.intel.com/en-us/intel-parallel-studio-xe"
diff --git a/var/spack/repos/builtin/packages/intel/package.py b/var/spack/repos/builtin/packages/intel/package.py
index 839d732bf8..4a923b37ac 100644
--- a/var/spack/repos/builtin/packages/intel/package.py
+++ b/var/spack/repos/builtin/packages/intel/package.py
@@ -9,8 +9,12 @@ import llnl.util.tty as tty
from spack.package import *
+@IntelOneApiPackage.update_description
class Intel(IntelPackage):
- """Intel Compilers."""
+ """Intel Compilers. This package has been replaced by
+ intel-oneapi-compilers.
+
+ """
homepage = "https://software.intel.com/en-us/intel-parallel-studio-xe"
diff --git a/var/spack/repos/builtin/packages/intel-daal/package.py b/var/spack/repos/builtin/packages/intel-daal/package.py
index efa8fef638..9f4fe05684 100644
--- a/var/spack/repos/builtin/packages/intel-daal/package.py
+++ b/var/spack/repos/builtin/packages/intel-daal/package.py
@@ -6,8 +6,12 @@
from spack.package import *
+@IntelOneApiPackage.update_description
class IntelDaal(IntelPackage):
- """Intel Data Analytics Acceleration Library."""
+ """Intel Data Analytics Acceleration Library. This package has been
+ replace by intel-oneapi-dal.
+
+ """
maintainers = ['rscohn2']
diff --git a/var/spack/repos/builtin/packages/intel-ipp/package.py b/var/spack/repos/builtin/packages/intel-ipp/package.py
index 2ef75242b4..3552ec676b 100644
--- a/var/spack/repos/builtin/packages/intel-ipp/package.py
+++ b/var/spack/repos/builtin/packages/intel-ipp/package.py
@@ -6,8 +6,14 @@
from spack.package import *
+@IntelOneApiPackage.update_description
class IntelIpp(IntelPackage):
- """Intel Integrated Performance Primitives."""
+ """Intel Integrated Performance Primitives. This package has been
+ replaced by intel-oneapi-ipp.
+
+ """
+
+ maintainers = ['rscohn2']
homepage = "https://software.intel.com/en-us/intel-ipp"
diff --git a/var/spack/repos/builtin/packages/intel-mkl/package.py b/var/spack/repos/builtin/packages/intel-mkl/package.py
index e5dca9dfe2..487a3e19ca 100644
--- a/var/spack/repos/builtin/packages/intel-mkl/package.py
+++ b/var/spack/repos/builtin/packages/intel-mkl/package.py
@@ -8,8 +8,12 @@ import sys
from spack.package import *
+@IntelOneApiPackage.update_description
class IntelMkl(IntelPackage):
- """Intel Math Kernel Library."""
+ """Intel Math Kernel Library. This package has been replaced by
+ intel-oneapi-mkl.
+
+ """
maintainers = ['rscohn2']
diff --git a/var/spack/repos/builtin/packages/intel-oneapi-ccl/package.py b/var/spack/repos/builtin/packages/intel-oneapi-ccl/package.py
index b1778719f9..695f9033ae 100644
--- a/var/spack/repos/builtin/packages/intel-oneapi-ccl/package.py
+++ b/var/spack/repos/builtin/packages/intel-oneapi-ccl/package.py
@@ -10,7 +10,15 @@ from spack.package import *
@IntelOneApiPackage.update_description
class IntelOneapiCcl(IntelOneApiLibraryPackage):
- """Intel oneAPI CCL."""
+ """The Intel oneAPI Collective Communications Library (oneCCL) enables
+ developers and researchers to more quickly train newer and
+ deeper models. This is done by using optimized communication
+ patterns to distribute model training across multiple
+ nodes. The library is designed for easy integration into deep
+ learning frameworks, whether you are implementing them from
+ scratch or customizing existing ones.
+
+ """
maintainers = ['rscohn2']
diff --git a/var/spack/repos/builtin/packages/intel-oneapi-dpl/package.py b/var/spack/repos/builtin/packages/intel-oneapi-dpl/package.py
index ca6ef530dc..d41ce1c3ed 100644
--- a/var/spack/repos/builtin/packages/intel-oneapi-dpl/package.py
+++ b/var/spack/repos/builtin/packages/intel-oneapi-dpl/package.py
@@ -11,7 +11,14 @@ from spack.package import *
@IntelOneApiPackage.update_description
class IntelOneapiDpl(IntelOneApiLibraryPackage):
- """Intel oneAPI DPL."""
+ """The Intel oneAPI DPC++ Library (oneDPL) is a companion to the Intel
+ oneAPI DPC++/C++ Compiler and provides an alternative for C++
+ developers who create heterogeneous applications and
+ solutions. Its APIs are based on familiar standards-C++ STL,
+ Parallel STL (PSTL), Boost.Compute, and SYCL*-to maximize
+ productivity and performance across CPUs, GPUs, and FPGAs.
+
+ """
maintainers = ['rscohn2']
diff --git a/var/spack/repos/builtin/packages/intel-oneapi-mkl/package.py b/var/spack/repos/builtin/packages/intel-oneapi-mkl/package.py
index 3b41efbdf8..2f47cf3fb7 100644
--- a/var/spack/repos/builtin/packages/intel-oneapi-mkl/package.py
+++ b/var/spack/repos/builtin/packages/intel-oneapi-mkl/package.py
@@ -11,7 +11,14 @@ from spack.package import *
@IntelOneApiPackage.update_description
class IntelOneapiMkl(IntelOneApiLibraryPackage):
- """Intel oneAPI MKL."""
+ """Intel oneAPI Math Kernel Library (Intel oneMKL; formerly Intel Math
+ Kernel Library or Intel MKL), is a library of optimized math
+ routines for science, engineering, and financial
+ applications. Core math functions include BLAS, LAPACK,
+ ScaLAPACK, sparse solvers, fast Fourier transforms, and vector
+ math.
+
+ """
maintainers = ['rscohn2']
diff --git a/var/spack/repos/builtin/packages/intel-oneapi-tbb/package.py b/var/spack/repos/builtin/packages/intel-oneapi-tbb/package.py
index 012c201a1b..88b1d8628d 100644
--- a/var/spack/repos/builtin/packages/intel-oneapi-tbb/package.py
+++ b/var/spack/repos/builtin/packages/intel-oneapi-tbb/package.py
@@ -11,7 +11,12 @@ from spack.package import *
@IntelOneApiPackage.update_description
class IntelOneapiTbb(IntelOneApiLibraryPackage):
- """Intel oneAPI TBB."""
+ """Intel oneAPI Threading Building Blocks (oneTBB) is a flexible
+ performance library that simplifies the work of adding
+ parallelism to complex applications across accelerated
+ architectures, even if you are not a threading expert.
+
+ """
maintainers = ['rscohn2']